@@ -177,12 +177,26 @@ def isnative(thing):
     """ isnative(thing) → boolean predicate, True if `thing`
         comes from a native-compiled (“extension”) module.
     """
-    module = moduleof(thing)
-    if module == 'builtins':
+    # Grab the name of the module of the thing:
+    module_name = moduleof(thing)
+    
+    # Not native:
+    if module_name == 'builtins':
         return False
-    return isnativemodule(
-           importlib.import_module(
-                            module))
+    
+    try:
+        # 99.99999999% of the time this should work
+        module = importlib.import_module(module_name)
+    except ModuleNotFoundError as error:
+        # This error indicates a native module, strangely:
+        if """named 'bin'""" in str(error):
+            return True
+    else:
+        # Delegate deciding about the module:
+        return isnativemodule(module)
+    
+    # We couldn’t figure this one out – so no false positives:
+    return False
 
 @export
 def isinspectable(thing):
@@ -235,7 +249,7 @@ def dotpath_split(dotpath):
 
 @export
 def qualified_import(qualified):
-    """ Import a qualified thing-name.
+    """ Import a thing based on its full thing-name.
         e.g. 'instakit.processors.halftone.FloydSteinberg'
     """
     if QUALIFIER not in qualified:
@@ -253,16 +267,18 @@ def qualified_name_tuple(thing):
     """ Get the thing-name and module/package name for a class or module.
         e.g. ('FloydSteinberg', 'instakit.processors.halftone')
     """
-    return nameof(thing), moduleof(thing)
+    from clu.predicates import pyqualname
+    return pyqualname(thing) or nameof(thing), \
+                              moduleof(thing)
 
 @export
 def qualified_name(thing):
-    """ Get a qualified thing-name for a thing.
+    """ Get a full thing-name for a thing.
         e.g. 'instakit.processors.halftone.FloydSteinberg'
     """
     thing_name, module_name = qualified_name_tuple(thing)
-    qualname = dotpath_join(module_name, thing_name)
-    return qualname
+    fullname = dotpath_join(module_name, thing_name)
+    return fullname
 
 @export
 def dotpath_to_prefix(dotpath, sep='-', end='-'):
