@@ -21,6 +21,12 @@ def checkmanifest(session):
     session.install("-r", "requirements/nox/manifest.txt")
     session.run('python', '-m', 'check_manifest', '-v')
 
+@nox.session
+def checkpyproject(session):
+    """ Validate CLU’s pyproject.toml """
+    session.install("-r", "requirements/nox/pyproject.txt")
+    session.run('validate-pyproject', '--verbose', 'pyproject.toml')
+
 @nox.session
 @nox.parametrize('module', (
     nox.param('clu.constants',      id='consts'),
